@@ -2,7 +2,7 @@
 # author: Ethosa
 from asyncio import sleep
 
-from aiohttp.client_exceptions import ClientOSError
+from aiohttp.client_exceptions import ClientConnectionError
 
 from ..VK.Event import event
 
@@ -78,7 +78,7 @@ class ALongPoll:
                     await self._get_server()
                 else:
                     return response
-            except ClientOSError:
+            except ClientConnectionError:
                 self._log(
                     "RequestsConnectionError happened, trying one more time"
                 )
